==> custom_pages-v1.12.6.zip: custom_pages/messages/th/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>เพิ่ม</strong> {templateName} รายการ',
    '<strong>Custom</strong> Pages' => '<strong>กำหนดเอง</strong> เพจ',
    '<strong>Edit</strong> snippet' => '<strong>แก้ไข</strong> ตัวอย่าง',
    'Add' => 'เพิ่ม',
    'Add a file icon before the title' => 'เพิ่มไอคอนไฟล์หน้าชื่อเรื่อง',
    'Adds plain HTML content to your site.' => 'เพิ่มเนื้อหา HTML ธรรมดาในเว็บไซต์ของคุณ',
    'Advanced' => 'ขั้นสูง',
    'Allows the user to manage custom pages.' => 'อนุญาตให้ผู้ใช้จัดการเพจที่กำหนดเอง',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'อนุญาตให้เพิ่มหน้า (markdown, iframe หรือลิงก์) ไปยังการนำทางอวกาศ',
    'Allows you to add content in MarkDown syntax.' => 'ให้คุณเพิ่มเนื้อหาในรูปแบบ MarkDown',
    'Alternate text' => 'ข้อความสำรอง',
    'Always make a backup of your view files outside of your production environment!' => 'สำรองข้อมูลไฟล์การดูของคุณนอกสภาพแวดล้อมการผลิตของคุณเสมอ!',
    'An empty allowed template selection will allow all container templates for this container.' => 'การเลือกเทมเพลตว่างที่อนุญาตจะอนุญาตให้ใช้เทมเพลตคอนเทนเนอร์ทั้งหมดสำหรับคอนเทนเนอร์นี้',
    'Back' => 'กลับ',
    'Back to dashboard' => 'กลับไปที่แดชบอร์ด',
    'Back to overview' => 'กลับไปที่ภาพรวม',
    'Back to space' => 'กลับสู่อวกาศ',
    'Can manage custom pages' => 'สามารถจัดการเพจที่กำหนดเองได้',
    'Category' => 'ประเภท',
    'Configuration' => 'การกำหนดค่า',
    'Content' => 'เนื้อหา',
    'Create' => 'สร้าง',
    'Css Class' => 'Css Class',
    'Custom' => 'กำหนดเอง',
    'Custom Pages' => 'หน้ากำหนดเอง',
    'Custom pages' => 'หน้ากำหนดเอง',
    'Dashboard' => 'แผงควบคุม',
    'Default' => 'ค่าเริ่มต้น',
    'Default Content' => 'เนื้อหาเริ่มต้น',
    'Delete' => 'ลบ',
    'Edit' => 'แก้ไข',
    'Edit Page' => 'แก้ไขหน้า',
    'Empty' => 'ว่างเปล่า',
    'File' => 'ไฟล์',
    'General' => 'ทั่วไป',
    'Html' => 'Html',
    'ID' => 'ไอดี',
    'Icon' => 'ไอคอน',
    'Iframe' => 'ไอเฟรม',
    'Insert' => 'แทรก',
    'Invalid request data!' => 'ข้อมูลคำขอไม่ถูกต้อง!',
    'Invalid template selection!' => 'การเลือกเทมเพลตไม่ถูกต้อง!',
    'Invalid type selection' => 'การเลือกประเภทไม่ถูกต้อง',
    'Invalid view file selection!' => 'การเลือกไฟล์ดูไม่ถูกต้อง!',
    'Link' => 'ลิงค์',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'การตั้งค่าเมนู',
    'Navigation' => 'การนำทาง',
    'On this page you can configure general settings of your custom pages.' => 'ในหน้านี้ คุณสามารถกำหนดการตั้งค่าทั่วไปของเพจที่คุณกำหนดเองได้',
    'Overview' => 'ภาพรวม',
    'PHP' => 'PHP',
    'Page' => 'หน้า',
    'Pages' => 'หน้า',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'โปรดเลือกประเภทเนื้อหาใดประเภทหนึ่งต่อไปนี้ ชนิดเนื้อหากำหนดวิธีการฝังเนื้อหาของคุณในไซต์ของคุณ',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'โปรดจำไว้ว่าเพจที่ใช้ php มีความเสี่ยงต่อปัญหาด้านความปลอดภัย โดยเฉพาะอย่างยิ่งเมื่อจัดการกับอินพุตของผู้ใช้ สำหรับข้อมูลเพิ่มเติม โปรดดูที่<a href="{url}">แนวทางปฏิบัติที่ดีที่สุดด้านความปลอดภัยของ Yii</a>',
    'Public' => 'สาธารณะ',
    'Reset' => 'รีเซ็ต',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'เลือกการตั้งค่านี้สำหรับโหนดข้อความที่มองเห็นเท่านั้น ยกเลิกการเลือกการตั้งค่านี้ในกรณีที่องค์ประกอบนี้ถูกใช้ เช่น เป็นค่าแอตทริบิวต์ HTML',
    'Settings' => 'การตั้งค่า',
    'Show additional file information (size)' => 'แสดงข้อมูลไฟล์เพิ่มเติม (ขนาด)',
    'Snippet' => 'Snippet',
    'Snippets' => 'ตัวอย่าง',
    'Sort Order' => 'เรียงลำดับ',
    'Source' => 'ที่มา',
    'Space' => 'อวกาศ',
    'Space Members only' => 'เฉพาะสมาชิกอวกาศ',
    'Space Navigation' => 'การนำทางอวกาศ',
    'Spaces' => 'ช่องว่าง',
    'Stream' => 'กระแส',
    'Stream options' => 'ตัวเลือกการสตรีม',
    'Style' => 'สไตล์',
    'Style Class' => 'สไตล์คลาส',
    'Submit' => 'ส่ง',
    'Target Url' => 'URL เป้าหมาย',
    'Template' => 'แม่แบบ',
    'Template Layout' => 'เค้าโครงเทมเพลต',
    'Templates' => 'แม่แบบ',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'เทมเพลตช่วยให้คุณกำหนดส่วนย่อยของหน้าที่รวมกันได้พร้อมฟังก์ชันแก้ไขแบบอินไลน์',
    'This container does not allow any further items!' => 'ตู้คอนเทนเนอร์นี้ไม่อนุญาตให้มีสิ่งของเพิ่มเติม!',
    'Title' => 'หัวข้อ',
    'Top Navigation' => 'การนำทางยอดนิยม',
    'Topics' => 'หัวข้อ',
    'Type' => 'พิมพ์',
    'Upload image' => 'อัพโหลดภาพ',
    'User Account Menu (Settings)' => 'เมนูบัญชีผู้ใช้ (การตั้งค่า)',
    'Visibility' => 'ทัศนวิสัย',
    'Will embed the result of a given url as an iframe element.' => 'จะฝังผลลัพธ์ของ url ที่กำหนดเป็นองค์ประกอบ iframe',
    'Will redirect requests to a given (relative or absolute) url.' => 'จะเปลี่ยนเส้นทางคำขอไปยัง URL ที่กำหนด (สัมพัทธ์หรือแบบสัมบูรณ์)',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'ด้วยเพจที่ใช้ PHP คุณสามารถสร้างเพจที่กำหนดเองได้ด้วยการดูไฟล์ในระบบไฟล์ของคุณ โปรดตรวจสอบการกำหนดค่าโมดูลสำหรับข้อมูลเพิ่มเติม',
    'Without adding to navigation (Direct link)' => 'โดยไม่ต้องเพิ่มการนำทาง (ลิงก์โดยตรง)',
    'You are not allowed to delete default content!' => 'คุณไม่ได้รับอนุญาตให้ลบเนื้อหาเริ่มต้น!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/th/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>เพิ่ม</strong> {templateName} รายการ',
    '<strong>Custom</strong> Pages' => '<strong>กำหนดเอง</strong> เพจ',
    '<strong>Edit</strong> snippet' => '<strong>แก้ไข</strong> ตัวอย่าง',
    'Add' => 'เพิ่ม',
    'Add a file icon before the title' => 'เพิ่มไอคอนไฟล์หน้าชื่อเรื่อง',
    'Adds plain HTML content to your site.' => 'เพิ่มเนื้อหา HTML ธรรมดาในเว็บไซต์ของคุณ',
    'Advanced' => 'ขั้นสูง',
    'Allows the user to manage custom pages.' => 'อนุญาตให้ผู้ใช้จัดการเพจที่กำหนดเอง',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'อนุญาตให้เพิ่มหน้า (markdown, iframe หรือลิงก์) ไปยังการนำทางอวกาศ',
    'Allows you to add content in MarkDown syntax.' => 'ให้คุณเพิ่มเนื้อหาในรูปแบบ MarkDown',
    'Alternate text' => 'ข้อความสำรอง',
    'Always make a backup of your view files outside of your production environment!' => 'สำรองข้อมูลไฟล์การดูของคุณนอกสภาพแวดล้อมการผลิตของคุณเสมอ!',
    'An empty allowed template selection will allow all container templates for this container.' => 'การเลือกเทมเพลตว่างที่อนุญาตจะอนุญาตให้ใช้เทมเพลตคอนเทนเนอร์ทั้งหมดสำหรับคอนเทนเนอร์นี้',
    'Back' => 'กลับ',
    'Back to dashboard' => 'กลับไปที่แดชบอร์ด',
    'Back to overview' => 'กลับไปที่ภาพรวม',
    'Back to space' => 'กลับสู่อวกาศ',
    'Can manage custom pages' => 'สามารถจัดการเพจที่กำหนดเองได้',
    'Category' => 'ประเภท',
    'Configuration' => 'การกำหนดค่า',
    'Content' => 'เนื้อหา',
    'Create' => 'สร้าง',
    'Css Class' => 'Css Class',
    'Custom' => 'กำหนดเอง',
    'Custom Pages' => 'หน้ากำหนดเอง',
    'Custom pages' => 'หน้ากำหนดเอง',
    'Dashboard' => 'แผงควบคุม',
    'Default' => 'ค่าเริ่มต้น',
    'Default Content' => 'เนื้อหาเริ่มต้น',
    'Delete' => 'ลบ',
    'Edit' => 'แก้ไข',
    'Edit Page' => 'แก้ไขหน้า',
    'Empty' => 'ว่างเปล่า',
    'File' => 'ไฟล์',
    'General' => 'ทั่วไป',
    'Html' => 'Html',
    'ID' => 'ไอดี',
    'Icon' => 'ไอคอน',
    'Iframe' => 'ไอเฟรม',
    'Insert' => 'แทรก',
    'Invalid request data!' => 'ข้อมูลคำขอไม่ถูกต้อง!',
    'Invalid template selection!' => 'การเลือกเทมเพลตไม่ถูกต้อง!',
    'Invalid type selection' => 'การเลือกประเภทไม่ถูกต้อง',
    'Invalid view file selection!' => 'การเลือกไฟล์ดูไม่ถูกต้อง!',
    'Link' => 'ลิงค์',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'การตั้งค่าเมนู',
    'Navigation' => 'การนำทาง',
    'On this page you can configure general settings of your custom pages.' => 'ในหน้านี้ คุณสามารถกำหนดการตั้งค่าทั่วไปของเพจที่คุณกำหนดเองได้',
    'Overview' => 'ภาพรวม',
    'PHP' => 'PHP',
    'Page' => 'หน้า',
    'Pages' => 'หน้า',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'โปรดเลือกประเภทเนื้อหาใดประเภทหนึ่งต่อไปนี้ ชนิดเนื้อหากำหนดวิธีการฝังเนื้อหาของคุณในไซต์ของคุณ',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'โปรดจำไว้ว่าเพจที่ใช้ php มีความเสี่ยงต่อปัญหาด้านความปลอดภัย โดยเฉพาะอย่างยิ่งเมื่อจัดการกับอินพุตของผู้ใช้ สำหรับข้อมูลเพิ่มเติม โปรดดูที่<a href="{url}">แนวทางปฏิบัติที่ดีที่สุดด้านความปลอดภัยของ Yii</a>',
    'Public' => 'สาธารณะ',
    'Reset' => 'รีเซ็ต',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'เลือกการตั้งค่านี้สำหรับโหนดข้อความที่มองเห็นเท่านั้น ยกเลิกการเลือกการตั้งค่านี้ในกรณีที่องค์ประกอบนี้ถูกใช้ เช่น เป็นค่าแอตทริบิวต์ HTML',
    'Settings' => 'การตั้งค่า',
    'Show additional file information (size)' => 'แสดงข้อมูลไฟล์เพิ่มเติม (ขนาด)',
    'Snippet' => 'Snippet',
    'Snippets' => 'ตัวอย่าง',
    'Sort Order' => 'เรียงลำดับ',
    'Source' => 'ที่มา',
    'Space' => 'อวกาศ',
    'Space Members only' => 'เฉพาะสมาชิกอวกาศ',
    'Space Navigation' => 'การนำทางอวกาศ',
    'Spaces' => 'ช่องว่าง',
    'Stream' => 'กระแส',
    'Stream options' => 'ตัวเลือกการสตรีม',
    'Style' => 'สไตล์',
    'Style Class' => 'สไตล์คลาส',
    'Submit' => 'ส่ง',
    'Target Url' => 'URL เป้าหมาย',
    'Template' => 'แม่แบบ',
    'Template Layout' => 'เค้าโครงเทมเพลต',
    'Templates' => 'แม่แบบ',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'เทมเพลตช่วยให้คุณกำหนดส่วนย่อยของหน้าที่รวมกันได้พร้อมฟังก์ชันแก้ไขแบบอินไลน์',
    'This container does not allow any further items!' => 'ตู้คอนเทนเนอร์นี้ไม่อนุญาตให้มีสิ่งของเพิ่มเติม!',
    'Title' => 'หัวข้อ',
    'Top Navigation' => 'การนำทางยอดนิยม',
    'Topics' => 'หัวข้อ',
    'Type' => 'พิมพ์',
    'Upload image' => 'อัพโหลดภาพ',
    'User Account Menu (Settings)' => 'เมนูบัญชีผู้ใช้ (การตั้งค่า)',
    'Visibility' => 'ทัศนวิสัย',
    'Will embed the result of a given url as an iframe element.' => 'จะฝังผลลัพธ์ของ url ที่กำหนดเป็นองค์ประกอบ iframe',
    'Will redirect requests to a given (relative or absolute) url.' => 'จะเปลี่ยนเส้นทางคำขอไปยัง URL ที่กำหนด (สัมพัทธ์หรือแบบสัมบูรณ์)',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'ด้วยเพจที่ใช้ PHP คุณสามารถสร้างเพจที่กำหนดเองได้ด้วยการดูไฟล์ในระบบไฟล์ของคุณ โปรดตรวจสอบการกำหนดค่าโมดูลสำหรับข้อมูลเพิ่มเติม',
    'Without adding to navigation (Direct link)' => 'โดยไม่ต้องเพิ่มการนำทาง (ลิงก์โดยตรง)',
    'You are not allowed to delete default content!' => 'คุณไม่ได้รับอนุญาตให้ลบเนื้อหาเริ่มต้น!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
